/*
* file CcAttribute.java
*
* Licensed Materials - Property of IBM
* Restricted Materials of IBM
* 
* com.ibm.rational.wvcm.stp.cc.CcAttribute
*
* (C) Copyright IBM Corporation 2007, 2008.  All Rights Reserved. 
* Note to U.S. Government Users Restricted Rights:  Use, duplication or  
* disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
*/

package com.ibm.rational.wvcm.stp.cc;

import java.util.Date;

import javax.wvcm.WvcmException;

import com.ibm.rational.wvcm.stp.cc.CcAttributeType.ValueType;

/**
 * <p>The ClearCase attribute mechanism lets you associate arbitrary
 * name/value pairs with particular ClearCase versions or elements.
 * </p>
 * <p>
 * This interface provides an aggregate object for handling these name/value 
 * pairs.
 * </p>
 */
public interface CcAttribute {
    
    /** Get the attribute's name. */
    public String getName() throws WvcmException;
    
    /** Get the type of the attribute's value data. */ 
    public CcAttributeType.ValueType getValueType();
    
    /** 
     * Get the attribute's value.
     * This call is valid for all value types where a string representation 
     * of the data is desired.
     */
    public String getValue();
    
    /** 
     * If the attribute's value type is INTEGER, retrieve it as such.
     * @throws Exception if value type is not INTEGER.
     */
    public int getIntegerValue() throws Exception;
    
    /** 
     * If the attribute's value type is REAL, retrieve it as such.
     * @throws Exception if value type is not REAL.
     */
    public double getRealValue() throws Exception;
 
    /** 
     * If the attribute's value type is TIME, retrieve it as such.
     * @throws Exception if value type is not TIME.
     */
    public Date getTimeValue() throws Exception;

    /** 
     * If the attribute's value type is STRING, retrieve it as such.
     * @throws Exception if value type is not STRING.
     */
    public String getStringValue() throws Exception;

    /** 
     * If the attribute's value type is OPAQUE, retrieve it as such.
     * @throws Exception if value type is not OPAQUE.
     */
    public byte [] getOpaqueValue() throws Exception;
    
}
